BOOST_PP_ARRAY_POP_FRONT

The BOOST_PP_ARRAY_POP_FRONT macro pops an element from the beginning of an array.

#### Usage

BOOST_PP_ARRAY_POP_FRONT(array)

#### Arguments

array
  The array to pop an element from.

#### Remarks

This macro returns array after removing the first element. If array has no elements, the result of applying this macro is undefined.
This macro uses BOOST_PP_REPEAT internally. Therefore, to use the z parameter passed from other macros that use BOOST_PP_REPEAT, see BOOST_PP_ARRAY_POP_FRONT_Z

#### See Also

- BOOST_PP_ARRAY_POP_FRONT_Z

#### Requirements

Header: <boost/preprocessor/array/pop_front.hpp>

#### Sample Code

    #include <boost/preprocessor/array/pop_front.hpp>

    #define ARRAY (3, (a, b, c))

    BOOST_PP_ARRAY_POP_FRONT(ARRAY) // expands to (2, (b, c))

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002
© Copyright Edward Diener 2013

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)